@@ -2,5 +2,5 @@
 
 /usr/bin/gconftool-2 --unset /system/osso/connectivity/network_type/GPRS/gprs_rx_bytes
 /usr/bin/gconftool-2 --unset /system/osso/connectivity/network_type/GPRS/gprs_tx_bytes
-/usr/bin/gconftool-2 --set /system/osso/connectivity/network_type/GPRS/gprs_reset_time --type=string $(date +%s)
+/usr/bin/gconftool-2 --set /system/osso/connectivity/network_type/GPRS/gprs_reset_time --type=string "$(date +%s)"
 
